roundhouse\.contrib\.serializers\.pickle module
===============================================

.. automodule:: roundhouse.contrib.serializers.pickle
    :members:
    :undoc-members:
    :show-inheritance:
